==> nextcloud-27.1.11.tgz: nextcloud/apps/activity/l10n/ka_GE.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "პერსონალურ აქტივობათა ლენტი მომხმარებლისთვის %s",
    "Your feed URL is invalid" : "თქვენი ლენტის URL არასწორია",
    "Activity feed" : "აქტივობათა ლენტი",
    "Your settings have been updated." : "თქვენი პარამეტრები განახლდა.",
    "Settings have been updated." : "პარამეტრები განახლდა.",
    "No activities" : "აქტივობები არაა",
    "_and %n more _::_and %n more _" : ["და კიდევ %n","და კიდევ %n"],
    "All activities" : "ყველა აქტივობა",
    "By others" : "სხვების მიერ",
    "By you" : "თქვენს მიერ",
    "Hello %s" : "გამარჯობა, %s",
    "Hello %s," : "გამარჯობა, %s,",
    "There was some activity at %s" : "%s-ზე იყო გარკვეული აქტივობა",
    "Mail" : "ფოსტა",
    "Activity" : "აქტივობა",
    "Notifications" : "შეტყობინებები",
    "Send email" : "ელ-წერილის გაგზავნა",
    "Today" : "დღეს",
    "Yesterday" : "გუშინ",
    "You need to set up your email address before you can receive notification emails." : "ელ-ფოსტაზე შეტყობინების მიღებამდე, საჭიროა მიუთითოთ თქვენი მისამართი.",
    "Send activity emails" : "აქტივობის ელ-წერილების გაგზავნა.",
    "As soon as possible" : "რაც შეიძლება მალე",
    "Hourly" : "საათობრივი",
    "Daily" : "ყოველდღიური",
    "Weekly" : "ყოველკვირეული",
    "You commented" : "თქვენ გააეკეთეთ კომენტარი",
    "in {path}" : "{path}-ში",
    "Home" : "სახლი",
    "This stream will show events like additions, changes & shares" : "ამ ნაკადში გამოჩნდება მოვლენების შესახებ ისეტი შეტყობინებები, როგორებიცაა დამატება, ცვლილება და გაზიარება",
    "No activity yet" : "ჯერ-ჯერობით აქტივობები არაა",
    "Enable RSS feed" : "RSS ლენტის გააქტიურება",
    "RSS feed" : "RSS ლენტა",
    "Notification" : "შეტყობინება",
    "Default settings" : "საწყისი პარამეტრები",
    "No more events to load" : "ყველა მოვლენა ჩამოტვირთულია",
    "Copied!" : "კოპირებულია!",
    "Not supported!" : "არ არის მხარდაჭერილი!",
    "Press ⌘-C to copy." : "კოპირებისთვის დააჭირეთ ⌘-C-ს.",
    "Press Ctrl-C to copy." : "კოპირებისთვის დააჭირეთ Ctrl-C-ს.",
    "{name} (invisible)" : "{name} (უჩინარი)",
    "{name} (restricted)" : "{name} (აკრძალული)",
    "There are no events for this filter" : "ამ ფილტრის შესაბამისი მოვლენები არაა"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-28.0.3.tgz: nextcloud/apps/activity/l10n/ka_GE.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "პერსონალურ აქტივობათა ლენტი მომხმარებლისთვის %s",
    "Your feed URL is invalid" : "თქვენი ლენტის URL არასწორია",
    "Activity feed" : "აქტივობათა ლენტი",
    "Your settings have been updated." : "თქვენი პარამეტრები განახლდა.",
    "Settings have been updated." : "პარამეტრები განახლდა.",
    "No activities" : "აქტივობები არაა",
    "_and %n more _::_and %n more _" : ["და კიდევ %n","და კიდევ %n"],
    "All activities" : "ყველა აქტივობა",
    "By others" : "სხვების მიერ",
    "By you" : "თქვენს მიერ",
    "Hello %s" : "გამარჯობა, %s",
    "Hello %s," : "გამარჯობა, %s,",
    "There was some activity at %s" : "%s-ზე იყო გარკვეული აქტივობა",
    "Mail" : "ფოსტა",
    "Activity" : "აქტივობა",
    "Notifications" : "შეტყობინებები",
    "Send email" : "ელ-წერილის გაგზავნა",
    "Today" : "დღეს",
    "Yesterday" : "გუშინ",
    "You need to set up your email address before you can receive notification emails." : "ელ-ფოსტაზე შეტყობინების მიღებამდე, საჭიროა მიუთითოთ თქვენი მისამართი.",
    "Send activity emails" : "აქტივობის ელ-წერილების გაგზავნა.",
    "As soon as possible" : "რაც შეიძლება მალე",
    "Hourly" : "საათობრივი",
    "Daily" : "ყოველდღიური",
    "Weekly" : "ყოველკვირეული",
    "You commented" : "თქვენ გააეკეთეთ კომენტარი",
    "in {path}" : "{path}-ში",
    "Home" : "სახლი",
    "This stream will show events like additions, changes & shares" : "ამ ნაკადში გამოჩნდება მოვლენების შესახებ ისეტი შეტყობინებები, როგორებიცაა დამატება, ცვლილება და გაზიარება",
    "No activity yet" : "ჯერ-ჯერობით აქტივობები არაა",
    "Enable RSS feed" : "RSS ლენტის გააქტიურება",
    "RSS feed" : "RSS ლენტა",
    "Notification" : "შეტყობინება",
    "Default settings" : "საწყისი პარამეტრები",
    "No more events to load" : "ყველა მოვლენა ჩამოტვირთულია",
    "Copied!" : "კოპირებულია!",
    "Not supported!" : "არ არის მხარდაჭერილი!",
    "Press ⌘-C to copy." : "კოპირებისთვის დააჭირეთ ⌘-C-ს.",
    "Press Ctrl-C to copy." : "კოპირებისთვის დააჭირეთ Ctrl-C-ს.",
    "{name} (invisible)" : "{name} (უჩინარი)",
    "{name} (restricted)" : "{name} (აკრძალული)",
    "There are no events for this filter" : "ამ ფილტრის შესაბამისი მოვლენები არაა",
    "Activities" : "აქტივობები"
},
"nplurals=2; plural=(n!=1);");
